@@ -6,8 +6,8 @@ import (
 	"io/ioutil"
 	"time"
 
-	"github.com/vbauerster/mpb/v6"
-	"github.com/vbauerster/mpb/v6/decor"
+	"github.com/vbauerster/mpb/v7"
+	"github.com/vbauerster/mpb/v7/decor"
 )
 
 func main() {
@@ -20,7 +20,7 @@ func main() {
 	)
 
 	bar := p.Add(total,
-		mpb.NewBarFiller("[=>-|"),
+		mpb.NewBarFiller(mpb.BarStyle().Rbound("|")),
 		mpb.PrependDecorators(
 			decor.CountersKibiByte("% .2f / % .2f"),
 		),
